@@ -38,17 +38,17 @@ def _delvewheel_init_patch_{0}():
     if sys.version_info[:2] >= (3, 8):
         if os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')):
             # backup the state of the environment variable CONDA_DLL_SEARCH_MODIFICATION_ENABLE
-            conda_dll_search_modification_enable = os.environ.get("CONDA_DLL_SEARCH_MODIFICATION_ENABLE")
-            os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE']='1'
+            conda_dll_search_modification_enable = os.environ.get('CONDA_DLL_SEARCH_MODIFICATION_ENABLE')
+            os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE'] = '1'
 
         os.add_dll_directory(libs_dir)
 
         if os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')):
             # restore the state of the environment variable CONDA_DLL_SEARCH_MODIFICATION_ENABLE
             if conda_dll_search_modification_enable is None:
-                os.environ.pop("CONDA_DLL_SEARCH_MODIFICATION_ENABLE", None)
+                os.environ.pop('CONDA_DLL_SEARCH_MODIFICATION_ENABLE', None)
             else:
-                os.environ["CONDA_DLL_SEARCH_MODIFICATION_ENABLE"] = conda_dll_search_modification_enable
+                os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE'] = conda_dll_search_modification_enable
     else:
         from ctypes import WinDLL
         with open(os.path.join(libs_dir, {2!r})) as file:
@@ -224,18 +224,26 @@ class WheelRepair:
                         docstring_search_start_index += len(line)
                     else:
                         break
-                docstring_start_index = init_contents.find('"""', docstring_search_start_index)
-                if docstring_start_index == -1:
+                double_quotes_index = init_contents.find('"""', docstring_search_start_index)
+                single_quotes_index = init_contents.find("'''", docstring_search_start_index)
+                if double_quotes_index == -1 and single_quotes_index == -1:
                     raise ValueError('Error parsing __init__.py: docstring exists but does not start with triple quotes')
-                docstring_end_index = init_contents.find('"""', docstring_start_index + 1) + 3
+                elif double_quotes_index == -1 or single_quotes_index != -1 and single_quotes_index < double_quotes_index:
+                    docstring_start_index = single_quotes_index
+                    quotes = "'''"
+                else:
+                    docstring_start_index = double_quotes_index
+                    quotes = '"""'
+                docstring_end_index = init_contents.find(quotes, docstring_start_index + 3)
                 if docstring_end_index == -1:
                     raise ValueError('Error parsing __init__.py: docstring exists but does not end with triple quotes')
+                docstring_end_index += 3
                 docstring_end_line = init_contents.find('\n', docstring_end_index)
                 if docstring_end_line == -1:
                     docstring_end_line = len(init_contents)
                 extra_text = init_contents[docstring_end_index: docstring_end_line]
                 if extra_text and not extra_text.isspace():
-                    raise ValueError(f'Error parsing __init__.py: extra text {extra_text!r} is on the line where the docstring ends')
+                    raise ValueError(f'Error parsing __init__.py: extra text {extra_text!r} is on the line where the docstring ends. Move the extra text to a new line and try again.')
                 with open(init_path, 'w') as file:
                     file.write(init_contents[:docstring_end_index])
                     file.write('\n')
